import {
  csv,
  max,
  select,
  timeParse,
  scaleTime,
  scaleLinear,
  axisBottom,
  axisLeft,
  brushX,
  extent,
} from 'd3';


// Set Sizing Constants
const svg = select('svg');
const svgWidth = +svg.attr('width');
const svgHeight = +svg.attr('height');
const margin = { top: 40, right: 60, bottom: 420, left: 60};
const width = svgWidth - margin.left - margin.right;
const height = svgHeight - margin.top - margin.bottom;


// Date Parser
const parseDate = timeParse('%b %Y');


// Set Scales and Axes
const x2 = scaleTime().range([0, width]);
const y2 = scaleLinear().range([height, 0]);

const xAxis2 = axisBottom(x2);
const yAxis = axisLeft(y2);


// Set Brush
const brush = brushX()
  .extent([[0, 0], [width, height]])
  .on('brush end', brushed);

// Set Area Functions
const area = d3.area()
  .curve(d3.curveMonotoneX)
  .x((d) => x(d.date))
  .y0(height)
  .y1((d) => y(d.price));
const area2 = d3.area()
  .curve(d3.curveMonotoneX)
  .x((d) => x2(d.date))
  .y0(height)
  .y1((d) => y2(d.price));


// Create Focus and Context Groups
const context = svg.append('g')
  .attr('class', 'context')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);


// Clip Off Brush-Zoom Overflow
svg.append('defs').append('clipPath')
    .attr('id', 'clip')
  .append('rect')
    .attr('width', width)
    .attr('height', height);


csv('data.csv', type).then((data) => {
  
  // Set Axes Domains
  x2.domain(extent(data, (d) => d.date));
  y2.domain([0, max(data, (d) => d.price)]);
  
  // Set Context Axes and Path
  context.append('path') // Data
    .datum(data)
    .attr('class', 'area')
    .attr('d', area2);
  context.append('g') // X-Axis
    .attr('class', 'axis axis--x')
    .attr('transform', `translate(0, ${height})`)
    .call(xAxis2);
  context.append('g') // Y-Axis
    .attr('class', 'brush')
    .call(brush)
    .call(brush.move, x2.range());
});


function brushed() {
  // let s = d3.event.selection || x2.range();
  // x.domain(s.map(x2.invert, x2));
  // focus.select('.area').attr('d', area);
  // focus.select('.axis--x').call(xAxis);
}


function type(d) {
  d.date = parseDate(d.date);
  d.price = +d.price;
  return d;
}











